@@ -2,11 +2,12 @@ import time
 
 from loreiosdk.spyglass_script import Spyglass
 
-url = 'wss://ui.getlore.io/storyteller'
-user = 'maurin'
-pwd = 'MA123$%'
+WS_URL = 'wss://ui.getlore.io/storyteller'
+USER = 'USER'
+PWD = 'PWD'
+DATASET = 'DS'
 
-spyglass = Spyglass(url, user, pwd, dataset_id='tvfplay')
+spyglass = Spyglass(WS_URL, USER, PWD, dataset_id=DATASET)
 
 tables = ['@TABLE_NAME']
 
